<?php

namespace AgileStoreLocator\Model;


if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

/**
*
* To access the Stores database table
*
* @package    AgileStoreLocator
* @subpackage AgileStoreLocator/elements/store
* @author     AgileStoreLocator Team <support@agilelogix.com>
*/
class Store {


  /**
   * [get_searchable_columns Return the list of searchable columns]
   * @return [type] [description]
   */
  public static function get_searchable_columns() {

    return ['id', 'title', 'lat', 'lng', 'street', 'city', 'state', 'postal_code', 'country', 'email', 'phone', 'fax', 'website', 'is_disabled', 'category', 'marker_id', 'logo_id', 'created_on'];
  }

  /**
   * [get_last_ts Return the last timestamp of updated_on or created_on]
   * @return [type] [description]
   */
  public static function get_last_ts() {

    global $wpdb;

    $ASL_PREFIX = ASL_PREFIX;
    
    $max_create = $wpdb->get_var("SELECT MAX(created_on) FROM `{$ASL_PREFIX}stores`");

    $max_update = $wpdb->get_var("SELECT MAX(updated_on) FROM `{$ASL_PREFIX}stores`");

    return ($max_create > $max_update)? $max_create: $max_update;
  }

  /**
   * [get_stores Get the stores by the given clause]
   * @param  array   $where_clause [description]
   * @param  [type]  $limit        [description]
   * @param  integer $offset       [description]
   * @return [type]                [description]
   */
  public static function get_stores($where_clause = [], $limit = 10000, $offset = 0) {

   
    global $wpdb;
    
    $ASL_PREFIX   = ASL_PREFIX;

    $category_clause = '';

    //  Validate the allowed clauses
    foreach($where_clause as $cl_key => $cl_value) {


      if(!in_array($cl_key, ['category', 'state', 'city', 'country'])) {
        unset($where_clause[$cl_key]);
      }
    }

    //  Categories Clause
    if(isset($where_clause['category'])) {

      $categories     = $where_clause['category'];
      $the_categories = array_map('intval', explode(',', $categories));
      $the_categories = implode(',', $the_categories);

      $category_clause = " AND {$ASL_PREFIX}stores_categories.`category_id` IN (".$the_categories.")";

      unset($where_clause['category']);
    }

    //  Get the ddl fields
    $ddl_fields  = \AgileStoreLocator\Model\Attribute::get_fields();


    // ddl_fields in the query
    $ddl_fields_str = implode(', ', array_map(function($f) { return "`$f`";}, $ddl_fields));

    //  Get the stores
    $query   = "SELECT s.`id`, `title`,  `description`, `street`,  `city`,  `state`, `postal_code`, `lat`,`lng`,`phone`,  `fax`,`email`,`website`,`logo_id`,{$ASL_PREFIX}storelogos.`path`,`marker_id`,`description_2`,`open_hours`, `ordr`, $ddl_fields_str, `custom`,`slug`, {$ASL_PREFIX}countries.`country` , `s`.`created_on`, `s`.`updated_on`
          FROM {$ASL_PREFIX}stores as s 
          LEFT JOIN {$ASL_PREFIX}storelogos ON logo_id = {$ASL_PREFIX}storelogos.id
          LEFT JOIN {$ASL_PREFIX}countries ON s.`country` = {$ASL_PREFIX}countries.id
          LEFT JOIN {$ASL_PREFIX}stores_categories ON s.`id` = {$ASL_PREFIX}stores_categories.store_id
          WHERE (is_disabled is NULL || is_disabled = 0) $category_clause";

    //  Add the category clause
    $str_clause = '';

    //  Must be an array
    if(!is_array($where_clause)) 
      $where_clause = [];

    //  Add the lang parameter, todo remove it from here
    $where_clause['lang'] = '';

    // loop over the clauses
    foreach($where_clause as $k => $value) {

      $str_clause      .= " AND {$k} = %s";
      $clause_params[]  = $value;
    }

    //  Add the clause
    $query .= $str_clause;

    $limit  = intval($limit);

    //  Prepare the limit clause
    $limit_clause = intval($offset).', '.intval($limit);

    $query .= " GROUP BY s.`id` ORDER BY `title` LIMIT $limit_clause;";

    //  Get the results
    $result = $wpdb->get_results($wpdb->prepare($query, $clause_params));

    return $result;
  }



  /**
   * [delete_store Delete a Store]
   * @param  [type] $store_id [description]
   * @return [type]           [description]
   */
  public static function delete_store($store_id) {

    global $wpdb;

    $ASL_PREFIX = ASL_PREFIX;

    // Delete Meta
    $wpdb->delete("{$ASL_PREFIX}stores_meta", array('store_id' => $store_id));

    //  Delete the store
    return $wpdb->delete("{$ASL_PREFIX}stores", array('id' => $store_id));
  }

}